@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class blacklistKeywordController(GracieBaseAPI):
-    """Keywords from a blacklist."""
+    """Blacklist Keyword Controller"""
 
     _controller_name = "blacklistKeywordController"
 
