@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class clusterSetController(GracieBaseAPI):
-    """Сluster set"""
+    """Cluster Set Controller"""
 
     _controller_name = "clusterSetController"
 
