@@ -14,7 +14,7 @@ class documentController(GracieBaseAPI):
             languageId: (string): languageId
             name: (string): name
             text: (type): text
-            weight: (number): weight
+            weight: (number): Document weight in range [-5,5]
 
         Consumes:
             application/json
@@ -104,7 +104,7 @@ class documentController(GracieBaseAPI):
             id: (string): id
             name: (string): name
             text: (type): text
-            weight: (number): weight
+            weight: (number): Document weight in range [-5,5]
 
         Consumes:
             application/json
