@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class enginesClusterController(GracieBaseAPI):
-    """Engines cluster"""
+    """Engines Cluster Controller"""
 
     _controller_name = "enginesClusterController"
 
