@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class featureCodeController(GracieBaseAPI):
-    """Features-codes."""
+    """Feature Code Controller"""
 
     _controller_name = "featureCodeController"
 
