@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class keywordController(GracieBaseAPI):
-    """Keywords."""
+    """Keyword Controller"""
 
     _controller_name = "keywordController"
 
@@ -13,7 +13,7 @@ class keywordController(GracieBaseAPI):
             folderId: (string): Id is some of { topic, topic-type, skillset, skill, cluster set, cluster group, cluster }
             languageId: (string): languageId
             name: (string): name
-            weight: (number): weight
+            weight: (number): Keyword weight in range [-2,2]
 
         Consumes:
             application/json
@@ -74,12 +74,12 @@ class keywordController(GracieBaseAPI):
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
-    def edit(self, id, weight):
+    def edit(self, id, **kwargs):
         """
 
         Args:
             id: (string): id
-            weight: (number): weight
+            weight: (number): Keyword weight in range [-2,2]
 
         Consumes:
             application/json
@@ -88,7 +88,7 @@ class keywordController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'id': {'name': 'id', 'required': True, 'in': 'query'}, 'weight': {'name': 'weight', 'required': True, 'in': 'query'}}
+        all_api_parameters = {'id': {'name': 'id', 'required': True, 'in': 'query'}, 'weight': {'name': 'weight', 'required': False, 'in': 'query'}}
         parameters_names_map = {}
         api = '/keyword/edit'
         actions = ['post']
