@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class languageController(GracieBaseAPI):
-    """Supported languages."""
+    """Language Controller"""
 
     _controller_name = "languageController"
 
