@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class mergeController(GracieBaseAPI):
-    """Databases"""
+    """Merge Controller"""
 
     _controller_name = "mergeController"
 
