@@ -7,7 +7,7 @@ class pipelineController(GracieBaseAPI):
     _controller_name = "pipelineController"
 
     def add(self, name, rules, **kwargs):
-        """Create new text processing pipeline for authenticated user.
+        """
 
         Args:
             description: (string): description
@@ -41,7 +41,7 @@ class pipelineController(GracieBaseAPI):
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def delete(self, id):
-        """Remove existing text processing pipeline for authenticated user.
+        """
 
         Args:
             id: (string): id
@@ -62,7 +62,7 @@ class pipelineController(GracieBaseAPI):
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def edit(self, id, **kwargs):
-        """Edit existing text processing pipeline by ID.
+        """
 
         Args:
             description: (string): description
@@ -108,7 +108,7 @@ class pipelineController(GracieBaseAPI):
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def retrieve(self, id):
-        """Return the text processing pipeline with specified ID.
+        """
 
         Args:
             id: (string): id
@@ -129,7 +129,7 @@ class pipelineController(GracieBaseAPI):
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def ruleOrigin(self, id, **kwargs):
-        """Return the rule.
+        """
 
         Args:
             id: (string): id
@@ -151,7 +151,7 @@ class pipelineController(GracieBaseAPI):
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
     def rulesOrigin(self, **kwargs):
-        """Return the list of all rules.
+        """
 
         Args:
             languageId: (string): languageId
