@@ -166,7 +166,7 @@ class profileController(GracieBaseAPI):
         """
 
         Args:
-            files: (array): files
+            files: (array): The format is TSV: https://en.wikipedia.org/wiki/Tab-separated_valuesFirst field is the label, which is a name of profile-class. The label is followed by a single tab character. The text is listed after a tab. Tab and newline characters are removed from the text before it's dumped to a file.
             id: (string): id
             languageId: (string): languageId
 
