@@ -2,14 +2,15 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class skillController(GracieBaseAPI):
-    """Skill"""
+    """Skill Controller"""
 
     _controller_name = "skillController"
 
-    def add(self, name, skillsetId):
+    def add(self, name, skillsetId, **kwargs):
         """
 
         Args:
+            description: (string): description
             name: (string): name
             skillsetId: (string): skillsetId
 
@@ -20,7 +21,7 @@ class skillController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'name': {'name': 'name', 'required': True, 'in': 'query'}, 'skillsetId': {'name': 'skillsetId', 'required': True, 'in': 'query'}}
+        all_api_parameters = {'description': {'name': 'description', 'required': False, 'in': 'query'}, 'name': {'name': 'name', 'required': True, 'in': 'query'}, 'skillsetId': {'name': 'skillsetId', 'required': True, 'in': 'query'}}
         parameters_names_map = {}
         api = '/skill/add'
         actions = ['post']
@@ -49,6 +50,28 @@ class skillController(GracieBaseAPI):
         params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
         return self._process_api(self._controller_name, api, actions, params, data, consumes)
 
+    def edit(self, id, **kwargs):
+        """
+
+        Args:
+            description: (string): description
+            id: (string): id
+
+        Consumes:
+            application/json
+
+        Returns:
+            application/json;charset=UTF-8
+        """
+
+        all_api_parameters = {'description': {'name': 'description', 'required': False, 'in': 'query'}, 'id': {'name': 'id', 'required': True, 'in': 'query'}}
+        parameters_names_map = {}
+        api = '/skill/edit'
+        actions = ['post']
+        consumes = ['application/json']
+        params, data = self._format_params_for_api(locals(), all_api_parameters, parameters_names_map)
+        return self._process_api(self._controller_name, api, actions, params, data, consumes)
+
     def list(self, skillsetId, **kwargs):
         """
 
