@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class skillParametersController(GracieBaseAPI):
-    """Skill parameters."""
+    """Skill Parameters Controller"""
 
     _controller_name = "skillParametersController"
 
@@ -10,6 +10,7 @@ class skillParametersController(GracieBaseAPI):
         """
 
         Args:
+            confidenceCurve: (string): JSON: {  // [0, 1]  double[21] confidenceNormalizationCurve,  // [0, max_double]  double bhattacharyyaDistance,  // [0, 1)  double validationSetQuality}
             languageId: (string): languageId
             normalizationHigherThreshold: (number): normalizationHigherThreshold
             normalizationLowerThreshold: (number): normalizationLowerThreshold
@@ -22,7 +23,7 @@ class skillParametersController(GracieBaseAPI):
             application/json;charset=UTF-8
         """
 
-        all_api_parameters = {'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}, 'normalizationHigherThreshold': {'name': 'normalizationHigherThreshold', 'required': False, 'in': 'query'}, 'normalizationLowerThreshold': {'name': 'normalizationLowerThreshold', 'required': False, 'in': 'query'}, 'skillId': {'name': 'skillId', 'required': True, 'in': 'query'}}
+        all_api_parameters = {'confidenceCurve': {'name': 'confidenceCurve', 'required': False, 'in': 'query'}, 'languageId': {'name': 'languageId', 'required': False, 'in': 'query'}, 'normalizationHigherThreshold': {'name': 'normalizationHigherThreshold', 'required': False, 'in': 'query'}, 'normalizationLowerThreshold': {'name': 'normalizationLowerThreshold', 'required': False, 'in': 'query'}, 'skillId': {'name': 'skillId', 'required': True, 'in': 'query'}}
         parameters_names_map = {}
         api = '/skillParameters/edit'
         actions = ['post']
