@@ -2,7 +2,7 @@ from gracie_dictionary_api import GracieBaseAPI
 
 
 class usersController(GracieBaseAPI):
-    """User - is someone who can edit data in the database.  All CRUD- operations possible to implement."""
+    """Users Controller"""
 
     _controller_name = "usersController"
 
